#!/usr/bin/env node
/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/

var express = require('express')
  , redis = require('redis').createClient()
  , csrf = require('express-csrf')
  , connect = require('connect')
  , redisStore = require('connect-redis')(connect)
  , ejs = require('ejs')
  , urlParser = require('url')
  , torrentServer = require('./lib/tracker/server.js')
  , event = require('./lib/core/event.js')
  , routeController = new require('./lib/core/routecontroller.js').routeController
  , argv = require('optimist')
  .usage("Usage: $0 --ip 0.0.0.0 --port 80")
  .demand(['ip', 'port'])
  .argv;

/**
 * Obtain a reference to express
 */
var app = module.exports = express.createServer();

/**
 * Create a new route controller which controls
 * all the routes for this application (including the torrent tracker)
 */
routeController = new routeController();

/**
 * Application configuration
 */
app.configure(function(){
  app.set('title', 'Distribute.it');
  app.set('views', __dirname + '/views');
  app.set('view engine', 'ejs');
  app.use(express.logger('  \033[90m:method\033[0m \033[36m:url\033[0m \033[90m:response-timems\033[0m'));
  app.use(express.bodyParser());
  app.use(express.cookieParser());
  app.use(express.session({ secret: "kljAKSLJElKJ#LkjLK#Jlkam.,m", store: new redisStore }))
  app.use(express.methodOverride());
  app.use(app.router);
  app.use(express['static'](__dirname + '/public'));
  app.use(express.errorHandler({ showStack: true, dumpExceptions: true }));
});

/**
 * Dynamic helper functions
 */
app.dynamicHelpers({
    // protection against csrf attacks
    csrf: csrf.token
});

/**
 * The route controller will find all routes that 
 * we have configured in separate files and initialize them.
 */
routeController.require('./views/src', { 
    database: redis,
    app: app,
    torrent: torrentServer
});

/**
 * If the user has not configured the platform all requests
 * will be piped to /setup. When the setup has finished
 * this no longer necessary.
 */
event.on('setup:unlock', function() {

    // check if there is a lock present
    if(!routeController.setupLock) return;
  
    // remove the lock file
    fs.unlink('setup.lock', function(err) {
       if(err) throw err; 
       
       // release the setup lock
       routeController.setupLock = false;

    });

});

/**
 * Listen on ip/port
 */
app.listen(argv.port, argv.ip);

console.log("Express server listening on port %d", app.address().port);