/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/

function routeHandler(global) {
        
    // current user session
    this.session = false;

    // add variables
    this.global = global;
    this.app = global.app;
    
    // url for current request
    this.requestUrl = false;
    
    // handler for get request
    this.method = {
        get: false,
        post: false,
        put: false,
        all: false,
        error: false
    } 
    
    // check if regex
    this.regex = false;
    
    return this;
    
}

/**
 * Determines if route is accessable for current user
 * @return {Boolean} True if accessable, False otherwise.
 */
routeHandler.prototype.isAccessable = function isAccessable() {
    return true;
}

/**
 * Allows you to set the access level required to access
 * a given route
 * @param {Array} permission 
 */
routeHandler.prototype.permission = function permission(permission) {
    return this;
}

/**
 * Configure the url this route should refer to
 * @param {String} url 
 * @return {This}
 */
routeHandler.prototype.url = function(url) {
    this.requestUrl = url;
    this.regex = Object.prototype.toString.call(url) === '[object RegExp]';
    return this;
}

/**
 * Callback that should be triggered if this should be a 'get' request
 * @param {Function} cb
 */
routeHandler.prototype.get = function(cb) {
    this.method.get = cb;
    return this;
}

/**
 * Callback that should be triggered if this should be a 'post' request
 * @param {Function} cb
 */
routeHandler.prototype.post = function(cb) {
    this.method.post = cb;
    return this;
}

/**
 * Callback that should be triggered if this should be a 'put' request
 * @param {Function} cb
 */
routeHandler.prototype.put = function(cb) {
    this.method.put = cb;
    return this;
}

/**
 * Callback that should be triggered if this should handle all types of requests
 * @param {Function} cb
 */
routeHandler.prototype.all = function(cb) {
    this.method.all = cb;
    return this;
}

/**
 * Callback for errors that occurs during request
 * @param {Function} cb
 */
routeHandler.prototype.error = function(cb) {
    this.method.error = cb;
    return this;
}

/**
 * Determines if a user is logged in
 * @return {Boolean} True if logged in, false otherwise
 */
routeHandler.prototype.hasSessionAuth = function hasSessionAuth() {
    return true;
}

exports.routeHandler = routeHandler;