/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/

/*!
* Module dependencies.
*/
var fs = require('fs')
, path = require('path');
    
/**
* Find all files recursively in a directory
* 
* Copyright: https://gist.github.com/825583
* 
* @param {String} directory Directory to read from 
* @param {Function} callback  
* @return {nil}
* @api public
*/
exports.readdir = function readdir(directory, callback) {
    
    // the final list of files
    var results = [];
    
    // read current directory
    fs.readdir(directory, function(err, list) {
        // an empty list or an error
        // is always passed to the callback
        if (err || !list) return callback(err, results);
        
        // create a serial loop
        (function next(i) {

            // if list[i] === undefind we know
            // we are finished because next(++i) always
            // increments +1 ahead of readdir()
            var file = list[i] 
            
                // the current file or directory we are working on
                , relative = directory + '/' + file; 

            // loop has finished (no more files to process)
            if (!file) return callback(null, results);
            
            // check if file is a directory or file
            fs.stat(relative, function(err, stat) {
                
                // pass errors to callback
                if(err) return callback(err, results);
                
                // check if relative path is a directory or a file
                if (stat.isDirectory()) {
                    
                    // get a list of files from current relative path
                    readdir(relative, function(err, files) {
                       
                        // append the files found to array
                        files.forEach(function(file) {
                            results.push(file); 
                        });
                        
                        // increment the file pointer
                        next(++i);
                        
                    });
                    
                } else {
                    
                    // push the current file to the result list
                    results.push(relative);
                    
                    // increment the file pointer
                    next(++i);
                    
                }
                
            });
            
        })(0);
    });
}
