/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/
function Event() {
    this.events = {};
    this.eventId = 0;
}

/**
 * Removes an event handler
 * 
 * @param {String} name The name of the event
 * @param {Number} eventId The id of the event callback you wish to remove
 * @return {Boolean}
 */
Event.prototype.remove = function(name, eventId) {
    if(this.events[name] && this.events[name][eventId]) {
        delete this.events[name][eventId];
        return true;
    }
    return false;
}

/**
 * Subscribe to an event
 * @param {String} name Name of the event you wish to subscribe to
 * @param {Function} callback Your callback function when an event is emitted
 * @return {Number} The event handler id
 */
Event.prototype.on = function(name, callback) {
    this.eventId++;
    if(!this.events[name]) this.events[name] = {};
    this.events[name][this.eventId] = callback;
    return this.eventId;
}

/**
 * Emit an specific event
 * @param {String} name Name of event you wish to trigger
 * @return 
 */
Event.prototype.emit = function(name) {
    if(this.events[name]) {
        for(var eventId in this.events[name]) {
            var args = Array.prototype.slice.call(arguments, 1),
                callback = this.events[name][eventId];
            callback.apply(null, args);
        }
    }
}

exports.event = event;
