/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/

var assert = require('assert');
var b = require('.././lib/tracker/util/bencode.js');

exports['decode integer 10'] = function(done) {
    assert.strictEqual(b.decode("i10e"), 10);
    done();
}

exports['decode integer 0 (zero)'] = function(done) {
    assert.strictEqual(b.decode("i0e"), 0);
    done();
}

exports['decode string "string"'] = function(done) {
    assert.strictEqual(b.decode("6:string"), "string");
    done();
}

exports['decode string empty list'] = function(done) {
    assert.strictEqual(b.decode("0:"), "");
    done();
}

exports['decode unicode string'] = function(done) {
    assert.strictEqual(b.decode("8:\x01string\x02"), "\x01string\x02");
    done();
}

exports['decode an array of integers'] = function(done) {
    assert.deepEqual(b.decode("li1ei2ei3ee"), [1, 2, 3]);
    done();
}

exports['decode an array with string and two integers'] = function(done) {
    assert.deepEqual(b.decode("l3:abci2ei3ee"), ["abc", 2, 3]);
    done();
}

exports['decode an array inside an array with mixed values'] = function(done) {
    assert.deepEqual(b.decode("l3:abcli1ei2eei3ee"), ["abc", [1, 2], 3]);
    done();
}

exports['decode an object'] = function(done) {
    assert.deepEqual(b.decode("d3:d-od1:k1:vee"),  { "d-o": { k: "v" } });
    done();
}

exports['decode an complex object'] = function(done) {
    assert.deepEqual(b.decode(
    "d1:03: - 1:bi42e1:cli1e3:defe3:d-od1:k1:ve1:k3:abce"), 
    { 0: " - ", k: "abc", b: 42, c: [1, "def"], "d-o": { k: "v" } }
    );
    done();
}