/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/

var assert = require('assert');
var b = require('.././lib/tracker/util/bencode.js');

exports['encode integer 10'] = function(done) {
    assert.strictEqual(b.encode(10), "i10e");
    done();
}

exports['encode integer 0 (zero)'] = function(done) {
    assert.strictEqual(b.encode(0), "i0e");
    done();
}

exports['encode string "string"'] = function(done) {
    assert.strictEqual(b.encode("string"), "6:string");
    done();
}

exports['encode string empty list'] = function(done) {
    assert.strictEqual(b.encode(""), "0:");
    done();
}

exports['encode unicode string'] = function(done) {
    assert.strictEqual(b.encode("\x01string\x02"), "8:\x01string\x02");
    done();
}

exports['encode an array of integers'] = function(done) {
    assert.deepEqual(b.encode([1, 2, 3]), "li1ei2ei3ee");
    done();
}

exports['encode an array with string and two integers'] = function(done) {
    assert.deepEqual(b.encode(["abc", 2, 3]), "l3:abci2ei3ee");
    done();
}

exports['encode an array inside an array with mixed values'] = function(done) {
    assert.deepEqual(b.encode(["abc", [1, 2], 3]), "l3:abcli1ei2eei3ee");
    done();
}

exports['encode an object'] = function(done) {
    assert.deepEqual(b.encode({ "d-o": { k: "v" } }), "d3:d-od1:k1:vee");
    done();
}

exports['encode an complex object'] = function(done) {
    assert.deepEqual(b.encode({ 0: " - ", k: "abc", b: 42, c: [1, "def"], "d-o": { k: "v" } }),
    "d1:03: - 1:bi42e1:cli1e3:defe3:d-od1:k1:ve1:k3:abce");
    done();
}